{% load cms_tags i18n %}
{% spaceless %}
{% if current_page.publisher_is_draft or instance.check_publication %}
  {% include "courses/cms/fragment_program_glimpse.html" with program=relevant_page.program %}
{% endif %}
{% endspaceless %}
