{% load i18n static %}{% spaceless %}
{% with full_page_url=SITE.web_url|add:page_url %}
    {% blocktrans with title=page_title asvar mailto_subject %}Richie news: {{ title }}{% endblocktrans %}
    {% blocktrans with title=page_title|safe url=full_page_url asvar shared_sentence %}Richie news: {{ title }} {{ url }}{% endblocktrans %}
    <div class="social-network-badges">
        <a
            href="https://www.facebook.com/share.php?u={{ full_page_url }}"
            class="social-network-badges__item"
            target="_blank"
            title="{% trans "Share on Facebook" %}"
        >
            <svg role="img">
                <use xlink:href="#icon-facebook" />
            </svg>
        </a>
        <a
            href="https://twitter.com/intent/tweet?text={{ shared_sentence|urlencode }}"
            class="social-network-badges__item"
            target="_blank"
            title="{% trans "Share on Twitter" %}"
        >
            <svg role="img">
                <use xlink:href="#icon-twitter" />
            </svg>
        </a>
        <a
            href="https://www.linkedin.com/sharing/share-offsite/?url={{ full_page_url }}"
            class="social-network-badges__item"
            target="_blank"
            title="{% trans "Share on Linkedin" %}"
        >
            <svg role="img">
                <use xlink:href="#icon-linkedin" />
            </svg>
        </a>
        <a
            href="mailto:?subject={{ mailto_subject|urlencode }}&amp;body={{ full_page_url|urlencode }}"
            class="social-network-badges__item"
            target="_blank"
            title="{% trans "Share by Email" %}"
        >
            <svg role="img">
                <use xlink:href="#icon-envelope" />
            </svg>
        </a>
    </div>
{% endwith %}
{% endspaceless %}
