(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[39680],{39680:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{as:{nu:["beng"],year:{0:"এই বছৰ",1:"অহা বছৰ",future:{one:"{0} বছৰত",other:"{0} বছৰত"},past:{one:"{0} বছৰৰ পূৰ্বে",other:"{0} বছৰৰ পূৰ্বে"},"-1":"যোৱা বছৰ"},"year-short":{0:"এই বছৰ",1:"অহা বছৰ",future:{one:"{0} বছৰত",other:"{0} বছৰত"},past:{one:"{0} বছৰৰ পূৰ্বে",other:"{0} বছৰৰ পূৰ্বে"},"-1":"যোৱা বছৰ"},"year-narrow":{0:"এই বছৰ",1:"অহা বছৰ",future:{one:"{0} বছৰত",other:"{0} বছৰত"},past:{one:"{0} বছৰৰ পূৰ্বে",other:"{0} বছৰৰ পূৰ্বে"},"-1":"যোৱা বছৰ"},quarter:{0:"এই তিনি মাহ",1:"অহা তিনি মাহ",future:{one:"{0} তিনি মাহত",other:"{0} তিনি মাহত"},past:{one:"{0} তিনি মাহ পূৰ্বে",other:"{0} তিনি মাহ পূৰ্বে"},"-1":"যোৱা তিনি মাহ"},"quarter-short":{0:"এই তিনি মাহ",1:"অহা তিনি মাহ",future:{one:"{0} তিনি মাহত",other:"{0} তিনি মাহত"},past:{one:"{0} তিনি মাহ পূৰ্বে",other:"{0} তিনি মাহ পূৰ্বে"},"-1":"যোৱা তিনি মাহ"},"quarter-narrow":{0:"এই তিনি মাহ",1:"অহা তিনি মাহ",future:{one:"{0} তিনি মাহত",other:"{0} তিনি মাহত"},past:{one:"{0} তিনি মাহ পূৰ্বে",other:"{0} তিনি মাহ পূৰ্বে"},"-1":"যোৱা তিনি মাহ"},month:{0:"এই মাহ",1:"অহা মাহ",future:{one:"{0} মাহত",other:"{0} মাহত"},past:{one:"{0} মাহ পূৰ্বে",other:"{0} মাহ পূৰ্বে"},"-1":"যোৱা মাহ"},"month-short":{0:"এই মাহ",1:"অহা মাহ",future:{one:"{0} মাহত",other:"{0} মাহত"},past:{one:"{0} মাহ পূৰ্বে",other:"{0} মাহ পূৰ্বে"},"-1":"যোৱা মাহ"},"month-narrow":{0:"এই মা.",1:"অহা মাহ",future:{one:"{0} মাহত",other:"{0} মাহত"},past:{one:"{0} মাহ পূৰ্বে",other:"{0} মাহ পূৰ্বে"},"-1":"যোৱা মা."},week:{0:"এই সপ্তাহ",1:"অহা সপ্তাহ",future:{one:"{0} সপ্তাহত",other:"{0} সপ্তাহত"},past:{one:"{0} সপ্তাহ পূৰ্বে",other:"{0} সপ্তাহ পূৰ্বে"},"-1":"যোৱা সপ্তাহ"},"week-short":{0:"এই সপ্তাহ",1:"অহা সপ্তাহ",future:{one:"{0} সপ্তাহত",other:"{0} সপ্তাহত"},past:{one:"{0} সপ্তাহ পূৰ্বে",other:"{0} সপ্তাহ পূৰ্বে"},"-1":"যোৱা সপ্তাহ"},"week-narrow":{0:"এই সপ্তাহ",1:"অহা সপ্তাহ",future:{one:"{0} সপ্তাহত",other:"{0} সপ্তাহত"},past:{one:"{0} সপ্তাহ পূৰ্বে",other:"{0} সপ্তাহ পূৰ্বে"},"-1":"যোৱা সপ্তাহ"},day:{0:"আজি",1:"কাইলৈ",2:"পৰহিলৈ",future:{one:"{0} দিনত",other:"{0} দিনত"},past:{one:"{0} দিন পূৰ্বে",other:"{0} দিন পূৰ্বে"},"-2":"পৰহি","-1":"কালি"},"day-short":{0:"আজি",1:"কাইলৈ",2:"পৰহিলৈ",future:{one:"{0} দিনত",other:"{0} দিনত"},past:{one:"{0} দিন পূৰ্বে",other:"{0} দিন পূৰ্বে"},"-2":"পৰহি","-1":"কালি"},"day-narrow":{0:"আজি",1:"কাইলৈ",2:"পৰহিলৈ",future:{one:"{0} দিনত",other:"{0} দিনত"},past:{one:"{0} দিন পূৰ্বে",other:"{0} দিন পূৰ্বে"},"-2":"পৰহি","-1":"কালি"},hour:{0:"এইটো ঘণ্টাত",future:{one:"{0} ঘণ্টাত",other:"{0} ঘণ্টাত"},past:{one:"{0} ঘণ্টা পূৰ্বে",other:"{0} ঘণ্টা পূৰ্বে"}},"hour-short":{0:"এইটো ঘণ্টাত",future:{one:"{0} ঘণ্টাত",other:"{0} ঘণ্টাত"},past:{one:"{0} ঘণ্টা পূৰ্বে",other:"{0} ঘণ্টা পূৰ্বে"}},"hour-narrow":{0:"এইটো ঘণ্টাত",future:{one:"{0} ঘণ্টাত",other:"{0} ঘণ্টাত"},past:{one:"{0} ঘণ্টা পূৰ্বে",other:"{0} ঘণ্টা পূৰ্বে"}},minute:{0:"এইটো মিনিটত",future:{one:"{0} মিনিটত",other:"{0} মিনিটত"},past:{one:"{0} মিনিট পূৰ্বে",other:"{0} মিনিট পূৰ্বে"}},"minute-short":{0:"এইটো মিনিটত",future:{one:"{0} মিনিটত",other:"{0} মিনিটত"},past:{one:"{0} মিনিট পূৰ্বে",other:"{0} মিনিট পূৰ্বে"}},"minute-narrow":{0:"এইটো মিনিটত",future:{one:"{0} মিনিটত",other:"{0} মিনিটত"},past:{one:"{0} মিনিট পূৰ্বে",other:"{0} মিনিট পূৰ্বে"}},second:{0:"এতিয়া",future:{one:"{0} ছেকেণ্ডত",other:"{0} ছেকেণ্ডত"},past:{one:"{0} ছেকেণ্ড পূৰ্বে",other:"{0} ছেকেণ্ড পূৰ্বে"}},"second-short":{0:"এতিয়া",future:{one:"{0} ছেকেণ্ডত",other:"{0} ছেকেণ্ডত"},past:{one:"{0} ছেকেণ্ড পূৰ্বে",other:"{0} ছেকেণ্ড পূৰ্বে"}},"second-narrow":{0:"এতিয়া",future:{one:"{0} ছেকেণ্ডত",other:"{0} ছেকেণ্ডত"},past:{one:"{0} ছেকেণ্ড পূৰ্বে",other:"{0} ছেকেণ্ড পূৰ্বে"}}}},availableLocales:["as"]})}}]);
//# sourceMappingURL=39680.789d6c637fe0bf206a63.index.js.map