{% extends "richie/fullwidth.html" %}
{% load category_tags cms_tags i18n pagination_tags %}

{% block subheader_content %}
<div class="subheader__container">
    <h1 class="subheader__title">{{ current_page.get_title }}</h1>
</div>
{% endblock subheader_content %}


{% block content %}{% spaceless %}
{% get_related_category_pages current_page.get_child_pages as categories %}
{% if categories %}
    <div class="category-tag-list category-tag-list--primary">
        <div class="category-tag-list__container">
            {% for category in categories %}
                {% include "courses/cms/fragment_category_glimpse.html" with category_variant="tag" %}
            {% endfor %}
        </div>
    </div>
{% endif %}

<div class="blogpost-list">
    {% if current_page.publisher_is_draft %}
        {% autopaginate current_page.get_child_pages 20 as object_list %}
    {% else %}
        {% autopaginate current_page.get_child_pages.published.distinct 20 as object_list %}
    {% endif %}
    {% for page in object_list %}
        {% if page.blogpost %}
            {% include "courses/cms/fragment_blogpost_glimpse.html" with blogpost=page.blogpost %}
        {% endif %}
    {% empty %}
        <p class="blogpost-glimpse blogpost-glimpse--empty">
            {% trans "No associated blogposts" %}
        </p>
    {% endfor %}

    {% if object_list %}
        {% paginate using "richie/pagination.html" %}
    {% endif %}
</div>
{% endspaceless %}{% endblock content %}
