{% load i18n static %}{% spaceless %}
    <a
        href="https://www.facebook.com/example"
        class="body-footer__badge"
        target="_blank"
    >
        <svg role="img">
            <title>{% trans "Facebook" %}</title>
            <use xlink:href="#icon-facebook" />
        </svg>
    </a>
    <a
        href="https://twitter.com/@funmooc"
        class="body-footer__badge"
        target="_blank"
        title="{% trans "Twitter page" %}"
    >
        <svg role="img">
            <title>{% trans "Twitter" %}</title>
            <use xlink:href="#icon-twitter" />
        </svg>
    </a>
    <a
        href="https://www.linkedin.com/school/franceuniversitenumerique/"
        class="body-footer__badge"
        target="_blank"
        title="{% trans "Linkedin" %}"
    >
        <svg role="img">
            <title>{% trans "Linkedin" %}</title>
            <use xlink:href="#icon-linkedin" />
        </svg>
    </a>
{% endspaceless %}
