(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[72777],{72777:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{ig:{nu:["latn"],year:{0:"Afọ a",1:"Afọ ọzọ",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Afọ gara aga"},"year-short":{0:"Afọ a",1:"Afọ ọzọ",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Afọ gara aga"},"year-narrow":{0:"Afọ a",1:"Afọ ọzọ",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Afọ gara aga"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"Ọnwa a",1:"Ọnwa ọzọ",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"Ọnwa gara aga"},"month-short":{0:"Ọnwa a",1:"Ọnwa ọzọ",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"Ọnwa gara aga"},"month-narrow":{0:"Ọnwa a",1:"Ọnwa ọzọ",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"Ọnwa gara aga"},week:{0:"Izu a",1:"Izu na-esote",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"Izu gara aga"},"week-short":{0:"Izu a",1:"Izu na-esote",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"Izu gara aga"},"week-narrow":{0:"Izu a",1:"Izu na-esote",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"Izu gara aga"},day:{0:"Taa",1:"Echi",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"Ụnyaahụ"},"day-short":{0:"Taata",1:"Echi",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"Ụnyaahụ"},"day-narrow":{0:"Taata",1:"Echi",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"Ụnyaahụ"},hour:{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-short":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-narrow":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},minute:{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-short":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-narrow":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},second:{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-short":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-narrow":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}}}},availableLocales:["ig"]})}}]);
//# sourceMappingURL=72777.789d6c637fe0bf206a63.index.js.map